intelmq.bots.parsers.fireeye package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.fireeye package

## Submodules

## intelmq.bots.parsers.fireeye.parser module

Fireeye Parser Bot Retrieves a base64 encoded JSON-String from raw and converts it into an event.

intelmq.bots.parsers.fireeye.parser.BOT

  alias of `intelmq.bots.parsers.fireeye.parser.FireeyeParserBot`

class intelmq.bots.parsers.fireeye.parser.FireeyeParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  init()
  process()

## Module contents